@@ -6,7 +6,12 @@ import os
 import time
 import threading
 
-from galaxy.tools.deps import dependencies
+try:
+    # If galaxy-lib or Galaxy 19.05 present.
+    from galaxy.tools.deps.dependencies import DependenciesDescription
+except ImportError:
+    # If galaxy-tool-util or Galaxy 19.09 present.
+    from galaxy.tool_util.deps.dependencies import DependenciesDescription
 
 from pulsar.client.util import filter_destination_params
 from pulsar.managers import ManagerProxy
@@ -58,6 +63,11 @@ class StatefulManagerProxy(ManagerProxy):
     def _default_status_change_callback(self, status, job_id):
         log.info("Status of job [%s] changed to [%s]. No callbacks enabled." % (job_id, status))
 
+    def trigger_state_change_callback(self, job_id):
+        proxy_status = self.get_status(job_id)
+        log.debug("Triggering state change callback with status %s by request for job_id %s", proxy_status, job_id)
+        self.__state_change_callback(proxy_status, job_id)
+
     @property
     def name(self):
         return self._proxied_manager.name
@@ -97,7 +107,8 @@ class StatefulManagerProxy(ManagerProxy):
                         'setup' in staging_config:
                     for action in staging_config['setup']:
                         action['action'].update(ssh_key=staging_config['action_mapper']['ssh_key'])
-                preprocess(job_directory, staging_config.get("setup", []), self.__preprocess_action_executor)
+                setup_config = staging_config.get("setup", [])
+                preprocess(job_directory, setup_config, self.__preprocess_action_executor, object_store=self.object_store)
                 self.active_jobs.deactivate_job(job_id, active_status=ACTIVE_STATUS_PREPROCESSING)
 
         new_thread_for_job(self, "preprocess", job_id, do_preprocess, daemon=False)
@@ -109,7 +120,7 @@ class StatefulManagerProxy(ManagerProxy):
             yield
             launch_kwds = {}
             if launch_config.get("dependencies_description"):
-                dependencies_description = dependencies.DependenciesDescription.from_dict(launch_config["dependencies_description"])
+                dependencies_description = DependenciesDescription.from_dict(launch_config["dependencies_description"])
                 launch_kwds["dependencies_description"] = dependencies_description
             for kwd in ["submit_params", "setup_params", "env"]:
                 if kwd in launch_config:
@@ -139,6 +150,9 @@ class StatefulManagerProxy(ManagerProxy):
         and track additional state information needed.
         """
         job_directory = self._proxied_manager.job_directory(job_id)
+        if not job_directory.exists():
+            return status.LOST
+
         with job_directory.lock("status"):
             proxy_status, state_change = self.__proxy_status(job_directory, job_id)
 
@@ -238,7 +252,7 @@ class StatefulManagerProxy(ManagerProxy):
                 self._launch_prepreprocessing_thread(job_id, launch_config)
 
         for unqueue_preprocessing_id in unqueue_preprocessing_ids:
-            self.active_job_directory.deactivate_job(unqueue_preprocessing_id, active_status=ACTIVE_STATUS_PREPROCESSING)
+            self.active_jobs.deactivate_job(unqueue_preprocessing_id, active_status=ACTIVE_STATUS_PREPROCESSING)
 
         recover_method = getattr(self._proxied_manager, "_recover_active_job", None)
         if recover_method is None:
@@ -336,7 +350,7 @@ class ManagerMonitor(object):
     def shutdown(self, timeout=None):
         self.active = False
         self.thread.join(timeout)
-        if self.thread.isAlive():
+        if self.thread.is_alive():
             log.warn("Failed to join monitor thread [%s]" % self.thread)
 
     def _run(self):
